@@ -28,8 +28,8 @@ class __Class(_pre.Pregex):
 
 
     def __init__(self, pattern: str, is_negated: bool, simplify_word: bool = False) -> '__Class':
+
         super().__init__(__class__.__simplify(pattern, is_negated, simplify_word), escape=False)
-        self._set_type(_pre._Type.Class)
         self.__is_negated = is_negated
         self.__verbose = pattern
 
@@ -109,7 +109,7 @@ class __Class(_pre.Pregex):
             elif isinstance(pre, _pre.Pregex) and pre._get_type() == _pre._Type.Token:
                 pre = AnyFrom(pre)
         if not issubclass(pre.__class__, __class__):
-            raise _exceptions.CannotBeUnionedException(self, pre, False)
+            raise _exceptions.CannotBeUnionedException(pre, False)
         return __class__.__or(self, pre)
 
 
@@ -127,7 +127,7 @@ class __Class(_pre.Pregex):
             elif isinstance(pre, _pre.Pregex) and pre._get_type() == _pre._Type.Token:
                 pre = AnyFrom(pre)
         if not issubclass(pre.__class__, __class__):
-            raise _exceptions.CannotBeUnionedException(pre, self, False)
+            raise _exceptions.CannotBeUnionedException(pre, False)
         return __class__.__or(pre, self)
 
 
@@ -140,7 +140,7 @@ class __Class(_pre.Pregex):
         :raises CannotBeUnionedException: 'pre1' is a different type of class than 'pre2'.
         '''
         if  pre1.__is_negated != pre2.__is_negated:
-            raise _exceptions.CannotBeUnionedException(pre1, pre2, True)
+            raise _exceptions.CannotBeUnionedException(pre2, True)
         if isinstance(pre1, Any) or isinstance(pre2, Any):
             return Any()
 
@@ -218,6 +218,7 @@ class __Class(_pre.Pregex):
             return set(f"{rng[0]}-{rng[1]}" for rng in ranges), set(chars)        
 
         ranges = reduce_ranges(ranges)
+
         ranges, chars = reduce_chars(list(ranges), list(chars))
 
         result =  __class__.__modify_classes(ranges.union(chars), escape=True)
@@ -241,7 +242,7 @@ class __Class(_pre.Pregex):
             elif isinstance(pre, _pre.Pregex) and pre._get_type() == _pre._Type.Token:
                 pre = AnyFrom(pre)
         if not issubclass(pre.__class__, __class__):
-            raise _exceptions.CannotBeSubtractedException(self, pre, False)
+            raise _exceptions.CannotBeSubtractedException(pre, False)
         return __class__.__sub(self, pre)
 
 
@@ -259,7 +260,7 @@ class __Class(_pre.Pregex):
             elif isinstance(pre, _pre.Pregex) and pre._get_type() == _pre._Type.Token:
                 pre = AnyFrom(pre)
         if not issubclass(pre.__class__, __class__):
-            raise _exceptions.CannotBeSubtractedException(pre, self, False)
+            raise _exceptions.CannotBeSubtractedException(pre, False)
         return __class__.__sub(pre, self)
 
 
@@ -273,7 +274,7 @@ class __Class(_pre.Pregex):
         :raises EmptyClassException: 'pre2' is an instance of class "Any".
         '''
         if  pre1.__is_negated != pre2.__is_negated:
-            raise _exceptions.CannotBeSubtractedException(pre1, pre2, True)
+            raise _exceptions.CannotBeSubtractedException(pre2, True)
         if isinstance(pre2, Any):
             raise _exceptions.EmptyClassException(pre1, pre2)
         if isinstance(pre1, Any):
@@ -390,7 +391,7 @@ class __Class(_pre.Pregex):
         classes = pattern[start_index:-1]
 
         # Extract classes separately.
-        ranges, chars = __class__.__extract_ranges(classes), __class__.__extract_chars(classes)
+        ranges, chars = __class__.__separate_classes(classes)
 
         # Escape their characters if you must.
         if unescape:
@@ -400,27 +401,19 @@ class __Class(_pre.Pregex):
         return ranges, chars
 
 
-    def __extract_ranges(classes: 'str') -> set[str]:
+    def __separate_classes(classes: 'str') -> tuple[set[str], set[str]]:
         '''
-        Extracts all ranges from the provided character class pattern and returns \
-        a set containing them.
+        Extracts all classes from the provided character class pattern and \
+        returns them separated into ranges and characters.
 
         :param str classes: One or more string character class patterns.
         '''
-        return set(_re.findall(
-            r"(?:\\(?:\[|\]|\^|\$|\-|\/|\\)|[^\[\]\^\$\-\/\\])-(?:\\(?:\[|\]|\^|\$|\-|\/|\\)|[^\[\]\^\$\-\/\\])",
-            classes, flags=_re.DOTALL))
-
-
-    def __extract_chars(classes: str) -> set[str]:
-        '''
-        Extracts all individual characters from the provided character class pattern \
-        and returns a set containing them.
-
-        :param str classes: One or more string character class patterns.
-        '''
-        return set(_re.findall(r"(?<!.\-)(?:\\(?:\[|\]|\^|\$|\-|\/|\\)|[^\[\]\^\$\-\/\\])(?!\-.)",
-            classes, flags=_re.DOTALL))
+        range_pattern = \
+            r"(?:\\(?:\[|\]|\^|\$|\-|\/|[a-z]|\\)|[^\[\]\^\$\-\/\\])" + \
+            r"-(?:\\(?:\[|\]|\^|\$|\-|\/|[a-z]|\\)|[^\[\]\^\$\-\/\\])"
+        ranges = set(_re.findall(range_pattern, classes))
+        classes = _re.sub(pattern=range_pattern, repl="", string=classes)
+        return (ranges, set(_re.findall(r"\\?.", classes, flags=_re.DOTALL)))
 
     
     def __modify_classes(classes: set[str], escape: bool) -> set[str]:
@@ -658,7 +651,7 @@ class AnyPunctuation(__Class):
         '''
         Matches any puncutation character as defined within the ASCII table.
         '''
-        super().__init__('[!-/:-@\[-`{-~]', is_negated=False)
+        super().__init__('[!-\/:-@\[-`{-~]', is_negated=False)
 
 
 class AnyButPunctuation(__Class):
@@ -672,7 +665,7 @@ class AnyButPunctuation(__Class):
         Matches any character except for punctuation characters \
         as defined within the ASCII table.
         '''
-        super().__init__('[^!-/:-@\[-`{-~]', is_negated=True)
+        super().__init__('[^!-\/:-@\[-`{-~]', is_negated=True)
 
 
 class AnyWhitespace(__Class):
@@ -703,32 +696,32 @@ class AnyBetween(__Class):
     '''
     Matches any character within the provided range.
 
-    :param str | int start: The first character of the range.
-    :param str | int end: The last character of the range.
+    :param str start: The first character of the range.
+    :param str end: The last character of the range.
 
     :raises NeitherCharNorTokenException: At least one of the provided characters \
         is neither a "token" class instance nor a single-character string.
     :raises InvalidRangeException: A non-valid range is provided.
 
-    :note: Any pair of characters "start", "end" constitutes a valid range, \
-        provided that the integer code point of "end" is greater than the \
-        integer code point of "start", as defined by the Unicode Standard.
+    :note: Any pair of characters "start", "end" constitutes a valid range \
+        as long as that the code point of "end" is greater than the code \
+        point of "start", as defined by the Unicode Standard.
     '''
 
     def __init__(self, start: str, end: str) -> 'AnyBetween':
         '''
         Matches any character within the provided range.
 
-        :param str | int start: The first character of the range.
-        :param str | int end: The last character of the range.
+        :param str start: The first character of the range.
+        :param str end: The last character of the range.
 
         :raises NeitherCharNorTokenException: At least one of the provided characters \
             is neither a "token" class instance nor a single-character string.
         :raises InvalidRangeException: A non-valid range is provided.
 
-        :note: Any pair of characters "start", "end" constitutes a valid range, \
-            provided that the integer code point of "end" is greater than the \
-            integer code point of "start", as defined by the Unicode Standard.
+        :note: Any pair of characters "start", "end" constitutes a valid range \
+            as long as that the code point of "end" is greater than the code \
+            point of "start", as defined by the Unicode Standard.
         '''
         for c in (start, end):
             if isinstance(c, (str, _pre.Pregex)):
@@ -748,32 +741,32 @@ class AnyButBetween(__Class):
     '''
     Matches any character except for all characters within the provided range.
 
-    :param str | int start: The first character of the range.
-    :param str | int end: The last character of the range.
+    :param str start: The first character of the range.
+    :param str end: The last character of the range.
 
     :raises NeitherCharNorTokenException: At least one of the provided characters \
         is neither a "token" class instance nor a single-character string.
     :raises InvalidRangeException: A non-valid range is provided.
 
-    :note: Any pair of characters "start", "end" constitutes a valid range, \
-        provided that the integer code point of "end" is greater than the \
-        integer code point of "start", as defined by the Unicode Standard.
+    :note: Any pair of characters "start", "end" constitutes a valid range \
+        as long as that the code point of "end" is greater than the code \
+        point of "start", as defined by the Unicode Standard.
     '''
 
     def __init__(self, start: str, end: str) -> 'AnyButBetween':
         '''
         Matches any character except for all characters within the provided range.
 
-        :param str | int start: The first character of the range.
-        :param str | int end: The last character of the range.
+        :param str start: The first character of the range.
+        :param str end: The last character of the range.
 
         :raises NeitherCharNorTokenException: At least one of the provided characters \
             is neither a "token" class instance nor a single-character string.
         :raises InvalidRangeException: A non-valid range is provided.
 
-        :note: Any pair of characters "start", "end" constitutes a valid range, \
-            provided that the integer code point of "end" is greater than the \
-            integer code point of "start", as defined by the Unicode Standard.
+        :note: Any pair of characters "start", "end" constitutes a valid range \
+            as long as that the code point of "end" is greater than the code \
+            point of "start", as defined by the Unicode Standard.
         '''
         for c in (start, end):
             if isinstance(c, (str, _pre.Pregex)):
