@@ -15,9 +15,7 @@ class __Operator(_pre.Pregex):
         result = __class__._to_pregex(pres[0])
         for pre in pres[1:]:
             result = _pre.Pregex(transform(result, __class__._to_pregex(pre)), escape=False)
-            result._set_type(type)
         super().__init__(str(result), escape=False)
-        self._set_type(type)
 
 
 class Concat(__Operator):
@@ -37,7 +35,7 @@ class Concat(__Operator):
 
         :raises LessThanTwoArgumentsException: Less than two arguments are provided.
         '''
-        super().__init__(pres, lambda pre1, pre2: pre1._concat(pre2), _pre._Type.Concat)
+        super().__init__(pres, lambda pre1, pre2: pre1._concat(pre2), _pre._Type.Other)
 
 
 class Either(__Operator):
